local AceGUI = LibStub("AceGUI-3.0")

PetBattleTeams_Advanced = {}

if PetBattleTeams then
	-- Get PetBattleTeams:TeamManager module
	local TeamManager =  PetBattleTeams:GetModule("TeamManager")
	if TeamManager then
		-- If GetTeamInformation does not exist => create the function
		if (TeamManager.GetTeamInformation == nil) then
			-- Function to add a description to the given Team.
			function TeamManager:GetTeamInformation(teamIndex)
				if type(teamIndex) ~= "number" then return "Unknown Team" end

				local name = "Description: "..tostring(teamIndex)
				local customName
				
				if self.teams[teamIndex] and self.teams[teamIndex].description then
					customName = self.teams[teamIndex].description
				end
				
				local displayName = customName and customName or name
				
				return displayName, name, customName
			end
		end

		-- If GetTeamInformation does not exist => create the function
		if (TeamManager.SetTeamInformation == nil) then
			function TeamManager:SetTeamInformation(teamIndex,description)
				assert(type(teamIndex) == "number"  and  (type(description) == "string" or description == nil))
				if  self.teams[teamIndex] then
					self.teams[teamIndex].description = description
				end
				self.callbacks:Fire("TEAM_UPDATED",teamIndex)
			end
		end

		if PetBattleTeamsUnitFrameMenu then
			table.insert(PetBattleTeamsUnitFrameMenu.menu, {
				text = "Information",
				notCheckable = true,
				func = function() 
					local teamIndex = PetBattleTeamsUnitFrameMenu.teamIndex  
					local petIndex = PetBattleTeamsUnitFrameMenu.petIndex
					local displayName = TeamManager:GetTeamName(teamIndex)

					-- Create a container frame
					local f = AceGUI:Create("Frame")
					f:SetCallback("OnClose",function(widget) AceGUI:Release(widget) end)
					f:SetTitle(displayName)
--					f:SetStatusText("Status Bar")
					f:SetWidth(400)
					f:SetHeight(300)
					f:SetLayout("Flow")

					local description = TeamManager:GetTeamInformation(teamIndex)
					local eb = AceGUI:Create("MultiLineEditBox")
					eb:SetLabel("Insert a description:")
					eb:SetRelativeWidth(1.0)
					eb:SetFullHeight(true)
					eb:SetText(description)
					eb:SetCallback("OnEnterPressed", function(_,_,data)
						TeamManager:SetTeamInformation(teamIndex, eb:GetText())
						f:SetStatusText("Description saved !")
					end)
					-- Add the edit box to the container
					f:AddChild(eb)
				end
			})
		end
	end

end

--[[
function IceHUD_Options:GenerateModuleOptions(firstLoad)
	self.options.args.modules.args = IceHUD.IceCore:GetModuleOptions()
	if not firstLoad then
		IceHUD:NotifyOptionsChange()
	end
end

function IceHUD_Options:OnLoad()
	self:GenerateModuleOptions(true)
	self.options.args.colors.args = IceHUD.IceCore:GetColorOptions()
	self.options.args.profiles = LibStub("AceDBOptions-3.0"):GetOptionsTable(IceHUD.db)

	-- Add dual-spec support
	if IceHUD.db ~= nil and LibDualSpec then
		LibDualSpec:EnhanceOptions(IceHUD_Options.options.args.profiles, IceHUD.db)
	end

	LibStub("AceConfig-3.0"):RegisterOptionsTable("IceHUD", options, "icehudcl")
end

if IceHUD and IceHUD.IceCore then
	IceHUD_Options:OnLoad()
end

function IceHUD_Options:SetupProfileImportButtons()
	if AceSerializer then
		AceSerializer:Embed(self)
		self.options.args.profiles.args.export = {
			type = 'execute',
			name = L["Export profile"],
			desc = L["Exports your active profile to something you can copy and paste to another user or use on another account."],
			func = function()
				local frame = AceGUI:Create("Frame")
				frame:SetTitle("Profile data")
				frame:SetStatusText("Exported profile details")
				frame:SetLayout("Flow")
				frame:SetCallback("OnClose", function(widget) AceGUI:Release(widget) end)
				local editbox = AceGUI:Create("MultiLineEditBox")
				editbox:SetLabel("Profile")
				editbox:SetFullWidth(true)
				editbox:SetFullHeight(true)
				local profileTable = deepcopy(IceHUD.db.profile)
				IceHUD:removeDefaults(profileTable, IceHUD.IceCore.defaults.profile)
				editbox:SetText(IceHUD:Serialize(profileTable))
				editbox:DisableButton(true)
				frame:AddChild(editbox)
			end,
			hidden =
				-- hello, snooper! this feature doesn't actually work yet, so enabling it won't help you much :)
				--@non-debug@
				true
				--@end-non-debug@
				--[===[@debug@
				false
				--@end-debug@]===]
			,
			disabled =
				-- hello, snooper! this feature doesn't actually work yet, so enabling it won't help you much :)
				--@non-debug@
				true
				--@end-non-debug@
				--[===[@debug@
				false
				--@end-debug@]===]
			,
			order = 98.1
		}

		self.options.args.profiles.args.import = {
			type = 'execute',
			name = L["Import profile"],
			desc = L["Imports a profile as exported from another user's IceHUD."],
			func = function()
				local frame = AceGUI:Create("Frame")
				frame:SetTitle("Profile data")
				frame:SetStatusText("Exported profile details")
				frame:SetLayout("Flow")
				frame:SetCallback("OnClose", function(widget)
					local success, newTable = IceHUD:Deserialize(widget.children[1]:GetText())
					if success then
						IceHUD:PreProfileChanged()
						IceHUD:populateDefaults(newTable, IceHUD.IceCore.defaults.profile)
						IceHUD.db.profile = deepcopy(newTable)
						IceHUD:PostProfileChanged()
					end
					AceGUI:Release(widget)
				end)
				local editbox = AceGUI:Create("MultiLineEditBox")
				editbox:SetLabel("Profile")
				editbox:SetFullWidth(true)
				editbox:SetFullHeight(true)
				editbox:DisableButton(true)
				frame:AddChild(editbox)
			end,
			hidden =
				-- hello, snooper! this feature doesn't actually work yet, so enabling it won't help you much :)
				--@non-debug@
				true
				--@end-non-debug@
				--[===[@debug@
				false
				--@end-debug@]===]
			,
			disabled =
				-- hello, snooper! this feature doesn't actually work yet, so enabling it won't help you much :)
				--@non-debug@
				true
				--@end-non-debug@
				--[===[@debug@
				false
				--@end-debug@]===]
			,
			order = 98.2
		}
	end
end

--[===[@debug@
IceHUD_Options:SetupProfileImportButtons()
--@end-debug@]===]
]]--
